@@ -92,7 +92,7 @@ ho = run_harmony(
 import pandas as pd
 import numpy as np
 #from scipy.cluster.vq import kmeans
-#from scipy.stats.stats import pearsonr
+from scipy.stats.stats import pearsonr
 #import harmonypy as hm
 
 meta_data = pd.read_csv("../harmonypy_extra_files/data/meta.tsv.gz", sep = "\t")
@@ -100,10 +100,10 @@ data_mat = pd.read_csv("../harmonypy_extra_files/data/pcs.tsv.gz", sep = "\t")
 data_mat = np.array(data_mat)
 vars_use = ['dataset', 'cell_type']
 
-ho = run_harmony(data_mat, meta_data, 'dataset', theta = 1, lamb = 0.1, max_iter_kmeans = 10, verbose = True)
+ho = run_harmony(data_mat, meta_data, 'dataset', theta = 1, lamb = 0.1, max_iter_harmony = 20, verbose = True)
 res = pd.DataFrame(ho.Z_corr).T
 res.columns = ['PC{}'.format(i + 1) for i in range(res.shape[1])]
-harm = pd.read_csv("data/300_cells_pcs_harmonized_dataset.tsv.gz", sep = "\t").T
+harm = pd.read_csv("../harmonypy_extra_files/data/300_cells_pcs_harmonized_dataset.tsv.gz", sep = "\t").T
 harm.columns = ['PC{}'.format(i + 1) for i in range(harm.shape[1])]
 cors = []
 for i in range(res.shape[1]):
@@ -142,7 +142,7 @@ import pandas as pd
 import numpy as np
 from scipy.cluster.vq import kmeans
 from scipy.stats.stats import pearsonr
-import harmonypy as hm
+# import harmonypy as hm
 from time import time
 
 meta_data = pd.read_csv("data/pbmc_3500_meta.tsv.gz", sep = "\t")
@@ -173,10 +173,12 @@ print([np.round(x[0], 3) for x in cors])
 # 59.59 seconds for 2e4 cells, 60.00 seconds for regular numpy
 df = pd.read_csv("~/work/github.com/slowkow/colitis/analysis/pegasus/case_control_pca.tsv.gz", sep = "\t")
 pcs = ["PC{}".format(i) for i in range(1, 31)]
-data_mat = df.loc[:20000,pcs]
-meta_data = df.loc[:20000,["cell","channel"]]
+n_cells = 20000
+data_mat = df.loc[:n_cells,pcs]
+meta_data = df.loc[:n_cells,["cell","channel"]]
 start = time()
-ho = hm.run_harmony(data_mat, meta_data, ['channel'])
+ho = run_harmony(data_mat, meta_data, ['channel'])
 end = time()
 print("elapsed {:.2f} seconds".format(end - start))
 
+
