@@ -21,7 +21,4 @@ def timereps(reps, func):
     return (end - start) / reps
 
 # 0.3 seconds per loop (too slow)
-timereps(10, lambda: hm.compute_lisi(X, metadata, label_colnames, perplexity))
-
-
-# Try https://github.com/rkern/line_profiler
+timereps(100, lambda: compute_lisi(X, metadata, label_colnames, n_neighbors))
